@@ -2,23 +2,27 @@ import base64
 import json
 import os
 
-from django import forms
+from django import forms, get_version
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.files.storage import Storage
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.template.defaultfilters import filesizeformat
-from django.utils import six
 from django.utils.translation import ugettext_lazy as _
 
+if get_version()[:3] == '1.3':
+    string_types = str
+else:
+    from django.utils.six import string_types
+
 import crocodoc
 from crocodoc import CrocodocError
 
 _token = 'CROCO_API_TOKEN'
 CROCO_API_TOKEN = getattr(settings, _token, os.environ.get(_token))
 if CROCO_API_TOKEN is None:
-    raise ImproperlyConfigured("CROCO_API_TOKEN setting is required."
+    raise ImproperlyConfigured("CROCO_API_TOKEN settings is required."
         " Define it in your project's settings.py or env.sh file.")
 
 crocodoc.api_token = CROCO_API_TOKEN
@@ -78,6 +82,18 @@ class CrocoFieldObject(object):
             'uuid': self.attrs['uuid']
         })
 
+    @property
+    def download_thumbnail(self):
+        return reverse('croco_thumbnail_download', kwargs={
+            'uuid': self.attrs['uuid']
+        })
+
+    @property
+    def download_text(self):
+        return reverse('croco_text_download', kwargs={
+            'uuid': self.attrs['uuid']
+        })
+
     def __unicode__(self):
         return "%s" % self.attrs['name']
 
@@ -102,10 +118,10 @@ class CrocoField(models.Field):
             return None
 
         try:
-            if isinstance(value, six.string_types):
+            if isinstance(value, string_types):
                 return CrocoFieldObject(self, json.loads(value))
         except ValueError:
-            pass
+            raise
         return value
 
     def pre_save(self, model_instance, add):
@@ -145,16 +161,16 @@ class CrocoField(models.Field):
             status = crocodoc.document.status(uuid)
             if status.get('error') is None:
                 try:
-                    thumb_attrs = {
+                    attrs = {
                         'width': self.thumbnail_size[0],
                         'height': self.thumbnail_size[1],
                     }
-                    thumbnail = crocodoc.download.thumbnail(uuid, **thumb_attrs)
-                    return "data:image/png;base64," + base64.b64encode(thumbnail)
+                    thumb = crocodoc.download.thumbnail(uuid, **attrs)
+                    return "data:image/png;base64," + base64.b64encode(thumb)
                 except CrocodocError as e:
                     return e.error_message
             else:
-                return e.error_message
+                return status.get('error')
         except CrocodocError as e:
             return e.error_message
 
@@ -163,9 +179,10 @@ class CrocoField(models.Field):
         return os.path.splitext(filename)[1][1:]
 
     def _is_document(self, filename):
-        """ """
+        allowed_exts = ('pdf', 'ppt', 'pptx', 'doc', 'docx', 'xls', 'xlsx',
+            'csv')
         _root, ext = os.path.splitext(filename.lower())
-        if ext[1:] in ('pdf', 'ppt', 'pptx', 'doc', 'docx', 'xls', 'xlsx', 'csv'):
+        if ext[1:] in allowed_exts:
             return True
         return False
 
