@@ -12,4 +12,10 @@ urlpatterns = patterns('',
     url(r'^croco_document_download/(?P<uuid>[-\w]+)$',
         views.CrocoDocumentDownload.as_view(),
         name='croco_document_download'),
+    url(r'^croco_thumbnail_download/(?P<uuid>[-\w]+)$',
+        views.CrocoThumbnailDownload.as_view(),
+        name='croco_thumbnail_download'),
+    url(r'^croco_text_download/(?P<uuid>[-\w]+)$',
+        views.CrocoTextDownload.as_view(),
+        name='croco_text_download'),
 )
